<?php

namespace Drupal\Tests\amazon_ses\Unit;

use Drupal\Tests\amazon_ses\Traits\MockMessageBuilderTrait;
use Drupal\Tests\UnitTestCase;
use Symfony\Component\Mime\Email;

/**
 * Tests the Amazon SES handler service.
 *
 * @group amazon_ses
 */
class MessageBuilderTest extends UnitTestCase {
  use MockMessageBuilderTrait;

  /**
   * Tests that the message is built.
   *
   * @dataProvider messageData
   */
  public function testBuildMessage($message) {
    $message_builder = $this->getMessageBuilder();
    $email = $message_builder->buildMessage($message);

    $this->assertInstanceOf(Email::class, $email);

    $to = $email->getTo();
    $this->assertEquals($to[0]->getAddress(), $message['to']);

    $from = $email->getFrom();
    $this->assertEquals($from[0]->getAddress(), $message['from']);

    $subject = $email->getSubject();
    $this->assertEquals($subject, $message['subject']);

    $body = $email->getTextBody();
    $this->assertEquals($body, $message['body']);
  }

  /**
   * Tests that an HTML message is built.
   *
   * @dataProvider messageData
   */
  public function testHtmlMessage($message) {
    $message['body'] = '<p>Test HTML message body</p>';
    $message['headers']['Content-Type'] = 'text/html';

    $message_builder = $this->getMessageBuilder();
    $email = $message_builder->buildMessage($message);

    $body = $email->getHtmlBody();
    $this->assertEquals($body, $message['body']);
  }

  /**
   * Provides message data for a successful message.
   */
  public function messageData() {
    return [
      [
        [
          'to' => 'to@example.com',
          'from' => 'from@example.com',
          'subject' => 'Amazon SES test',
          'body' => 'test message body',
          'headers' => [
            'Content-Type' => 'text/plain',
          ],
        ],
      ],
    ];
  }

}
